﻿"""
========================================================================================================
Ce programme Python permet de représenter les positions d'un point, son vecteur vitesse à chacune 
de ses positions, ainsi que le vecteur DeltaV moyen.

L'import des données fait appel au fichier 'import_donnees_meca.py', programmé par Olivier CHAMETTE et 
Jean-Baptiste BUTET (académie de LYON)
Les instructions permettant de générer le tableau de valeurs à partir des logiciels usuels de mécanique
sont données dans les commentaires.
========================================================================================================
"""

# importation de NUMPY (pour gestion tableaux et calculs) sous l'alias "np"
import numpy as np

# importation de PYPLOT (du module MATPLOTLIB, pour le tracé de courbes) sous l'alias "plt"
import matplotlib.pyplot as plt

# importation des données du pointage (le fichier "import_donnees.py" est indispensable)
from import_donnees_meca import traiteDonnees

# Initialisation des tableaux numpy contenant x,y,t 
x=np.array([])
y=np.array([])
t=np.array([])
# Initialisation des listes contenant Vx et Vy
Vx=[]
Vy=[]

# fonction pour le tracé simplifié d'un vecteur
def Trace_Vecteur(X_origine, Y_origine, X_vecteur, Y_vecteur, couleur) :
    plt.quiver(X_origine, Y_origine, X_vecteur, Y_vecteur, color=couleur, scale=40, headwidth=5, width=0.003)


""" -------------------------------------------------------------------------------------------------------
    Ligne 45 à renseigner par LE PROFESSEUR en fonction du logiciel utilisé par ses élèves pour le pointage
    ------------------------------------------------------------------------------------------------------- """
    #  Attribuer ç la variable Logiciel_Utilise l'une des valeurs suivantes : 
    # 'pymecavideo'     (exporter un fichier TXT)
    # 'latispro'        (fichier TXT créé par LATISPRO, avec décimale VIRGULE et séparation POINT VIRGULE)
    # 'avimeca'         (crééer un fichier TXT en export)
    # 'avistep'         (pointage exporté depuis AVISTEP:
    # 'equation'        (équation paramétrées saisies dans le fichier "import_donnees")
    # 'entrees'        (données de pointage saisies "à la main" dans le fichier "import_donnees.py)
Logiciel_Utilise = 'latispro'

t, x, y = traiteDonnees(Logiciel_Utilise)
n_max=len(t)-1 # numéro du dernier point, le premier étant le 0

# ==================================================================
# 1ère fenêtre graphique pour tracer les positions et les vecteurs v
# ==================================================================
plt.subplot(1, 2, 1) # divise l'écran en 1 ligne 2 colonne ; tout ce qui suit concerne la 1ère colonne

""" 
___________________________________________________________________________
ETAPE ELEVE n°1 : Programmer ci-dessous le tracé des positions enregistrées """



""" _____________________________FIN DE L'ETAPE n°1________________________ """



""" 
_________________________________________________________________________
ETAPE ELEVE n°2 : Programmer ci-dessous le calcul des valeurs de Vx et Vy """

n=0                 # n va varier de 0 à n_max, rang du dernier point enregistré
while n<n_max :     # cette instruction signifie : tant que n<n_max, fais ce qui suit
    # CONSIGNE : 
    # Dans la ligne qui suit, saisir la formule qui permet de compléter la liste des valeurs de Vx.  
    # La syntaxe à utiliser est : Vx.append(expression de Vx en fonction de x[n], x[n+1], t[n] et t[n+1]) 

    # CONSIGNE : idem ci-dessous avec Vy

    n=n+1           # à ne surtout par oublier, sinon le programme ne s'arrête jamais !

""" __________________________FIN DE L'ETAPE n°2_________________________ """


""" 
____________________________________________________________________________________________________________
ETAPE ELEVE n°3 : Programmer ci-dessous le tracé des vecteurs vitesse à partir des positions du point étudié """
    
# maintenant on se débrouille un peu tout seul !

""" __________________________________________FIN DE l'ETAPE n°3____________________________________________ """


# Ajout d'une légende pour chaque point
n=0
while n<len(x) : 
    plt.annotate(str(n), (x[n]-0.02,y[n]+0.02),fontsize=12, color="orange")
    n=n+1

# Légende, échelle et titre du graphique 
plt.legend(['positions', 'Vecteurs-vitesse'], loc='lower center')
plt.grid()
plt.axis('scaled')
plt.title('Position et vecteur vitesse du point étudié')    # titre du graphique
plt.xlabel('Abscisse X du point étudié (en m)')             # nom de la grandeur sur l'axe X
plt.ylabel('Ordonnée Y du point étudié (en m)')             # nom de la grandeur sur l'axe Y
plt.axis('equal')                                           # le repère doit être orthonormé


# ======================================================================
# 2ème graphique : les vecteurs v sont tracés à partir de la même orgine
# ====================================================================== 

plt.subplot(1, 2, 2)  # divise l'écran en 1 ligne 2 colonnes ; tout ce qui suit concerne la 2ème colonne

# Redéfinition de la fonction de tracé simplifiée des vecteurs (nécessaire pour des questions d'échelle)
def Trace_Vecteur(X_origine, Y_origine, X_vecteur, Y_vecteur, couleur) :
    plt.quiver(X_origine, Y_origine, X_vecteur, Y_vecteur, color=couleur, units='xy', scale=1, headwidth=6, width=0.015)

# On représente Vy en fonction de Vx (avec une couleur transparente) afin que le repère soit à la bonne échelle 
if len(Vx)>0 : 
    Limite_Vx=[min(Vx), max(Vx)]
    minVy=min(0,min(Vy))
    EcartVy=abs(max(Vy)-minVy)
    Limite_Vy=[minVy -0.25*EcartVy, max(Vy)]
    plt.plot(Vx,Vy, alpha=0, label='_nolegend_') # le tracé est transparent et ne figure pas dans la légende
    plt.plot(Limite_Vx,Limite_Vy, alpha=0, label='_nolegend_') # le tracé est transparent et ne figure pas dans la légende


""" 
__________________________________________________________________________________________________________
ETAPE ELEVE n°4 : programmer ci-dessous le tracé des vecteurs-vitesse à partir de l'origine du 2ème repère """



""" ____________________________________FIN DE l'ETAPE n°4________________________________________________ """



""" 
________________________________________________________________________________________________________
ETAPE ELEVE n°5 : programmer ci-dessous le calcul des coordonnées DeltaVx et DeltaVy de la variation 
                  du vecteurs-vitesse, ainsi que son tracé à partir de la pointe du premier vecteur v  """



""" ___________________________________FIN DE l'ETAPE n°5____________________________________________ """


# Titre et légende des axes du seconde graphique
plt.legend(['vecteurs-vitesse', 'variation du vecteur-vitesse pendant la chute'], loc='lower center')
plt.title('vecteur-vitesse et variation du vecteur-vitesse')
plt.xlabel('Vx (en m/s)')
plt.ylabel('Vy (en m/s)')
plt.axis('equal')
plt.grid()

# on affiche le résultat
plt.get_current_fig_manager().window.state('zoomed')   # Affiche la fenêtre maximisée sous windows uniquement
plt.show()
